import React, { useEffect, useState } from "react";
import useLanguage from "../../hooks/useLanguage";

function CartSummery({ products, checkout, disabledCheckout }) {
  const language = useLanguage();
  const [totalWeight, setTotalWeight] = useState(0);
  useEffect(() => {
    const weight = products.reduce(
      (total, product) =>
        total +
        product.products.reduce((tot, pro) => Number(tot) + Number(pro.qty), 0),
      0
    );
    setTotalWeight(weight);
  }, [products]);

  return (
    <div className=" rounded-lg bg-primary-200 text-white p-7 flex gap-4 flex-col">
      <div className="border-b border-white border-opacity-20">
        <p className=" text-lg mb-1">{language["Total Supplier Shop"]}</p>
        <h1 className=" text-2xl font-bold mb-4">{products.length}</h1>
      </div>
      <div className="border-b border-white border-opacity-20">
        <p className=" text-lg mb-1">{language["Total Item"]}</p>
        <h1 className=" text-2xl font-bold mb-4">
          {products.reduce(
            (total, product) => total + product.products.length,
            0
          )}
        </h1>
      </div>
      <div className="border-b border-white border-opacity-20">
        <p className=" text-lg mb-1 notranslate">{language["Total Weight"]}</p>
        <h1 className=" text-2xl font-bold mb-4">
          {totalWeight + " " + language["Ton"]}
        </h1>
      </div>
      <div>
        <p className=" text-lg mb-1">{["Total Amount"]}</p>
        <h1 className=" text-2xl font-bold mb-4">
          {Number(
            products.reduce(
              (total, product) =>
                total +
                product.products.reduce(
                  (tot, pro) =>
                    (
                      Number(tot) +
                      Number(
                        pro?.warehouse_product.price
                          ? pro?.warehouse_product.price
                          : pro.product.price
                      ) *
                        Number(pro.qty)
                    ).toFixed(2),
                  0
                ),
              0
            )
          )}
          $
        </h1>
      </div>
      <button
        className=" text-dark-300 text-sm font-medium px-7 py-3 rounded  disabled:bg-opacity-70 bg-secondary bg-opacity-100  transition-all duration-500  relative animated-btn notranslate"
        disabled={disabledCheckout}
        onClick={() => checkout((prev) => !prev)}
      >
        {language["Check Out"]}
      </button>
    </div>
  );
}

export default CartSummery;
